#define WIN32_LEAN_AND_MEAN
#include "windows.h"

BOOL WINAPI MainDlgProc( HWND, UINT, WPARAM, LPARAM );
BOOL DoTapeSize( HWND );


HINSTANCE hInst;


int APIENTRY WinMain( HINSTANCE hInstance, HINSTANCE hPrev, LPSTR lpCmd,
                      int nShow )
{
   hInst = hInstance;
   DialogBox( hInst, MAKEINTRESOURCE( 10000 ), NULL, MainDlgProc );
   return( FALSE );
}


BOOL WINAPI MainDlgProc( HWND hDlg, UINT msg, WPARAM wParam, LPARAM lParam )
{
   switch( msg )
   {
      case WM_INITDIALOG:
         DoTapeSize( hDlg );
         return( TRUE );

      case WM_COMMAND:
         if( wParam == IDCANCEL )
         {
            EndDialog( hDlg, TRUE );
            return( TRUE );
         }
         break;
   }
   return( FALSE );
}


BOOL DoTapeSize( HWND hWnd )
{
   HANDLE hFile;
   DWORD dwSize, dwStatus;
   TAPE_GET_MEDIA_PARAMETERS tgmp;
   char szOutput[ 64 ];

   hFile = CreateFile( "\\\\.\\TAPE0",                  //  Open the tape drive
                       GENERIC_READ | GENERIC_WRITE,   //  This defaults to the
                       0, 0, OPEN_EXISTING, 0, NULL );     //  first tape drive
   if( hFile == INVALID_HANDLE_VALUE )
      return( FALSE );                                  //  Exit if open failed
                     //  This is important...nothing really works if not called
   dwStatus = PrepareTape( hFile, TAPE_LOCK, FALSE );
   if( dwStatus != NO_ERROR && 
       dwStatus != ERROR_MEDIA_CHANGED )  //  Media change is apparently common
   {                                      //  so don't fail if that's the error
      wsprintf( szOutput, "Error %d with PrepareTape()", dwStatus );
      SendDlgItemMessage( hWnd, 100, LB_ADDSTRING, 0, (LPARAM)szOutput );
      CloseHandle( hFile );
      return( FALSE );
   }

   dwStatus = GetTapeStatus( hFile );         //  Wait for the tape to be ready
   if( dwStatus != NO_ERROR )        //  Which it should be after PrepareTape()
   {
      wsprintf( szOutput, "Error %d with GetTapeStatus()", dwStatus );
      SendDlgItemMessage( hWnd, 100, LB_ADDSTRING, 0, (LPARAM)szOutput );
      CloseHandle( hFile );
      return( FALSE );
   }

   memset( &tgmp, 0, sizeof(TAPE_GET_MEDIA_PARAMETERS) );
   dwSize = sizeof(TAPE_GET_MEDIA_PARAMETERS);          //  Get tape parameters
   dwStatus = GetTapeParameters( hFile, GET_TAPE_MEDIA_INFORMATION,
                                 &dwSize, &tgmp );

   if( dwStatus == NO_ERROR )             //  If no error, show tape parameters
   {
      wsprintf( szOutput, "Block Size: %d", tgmp.BlockSize );
      SendDlgItemMessage( hWnd, 100, LB_ADDSTRING, 0, (LPARAM)szOutput );
      wsprintf( szOutput, "Partition Count: %d", tgmp.PartitionCount );
      SendDlgItemMessage( hWnd, 100, LB_ADDSTRING, 0, (LPARAM)szOutput );
      wsprintf( szOutput, "Write Protected: %d", tgmp.WriteProtected );
      SendDlgItemMessage( hWnd, 100, LB_ADDSTRING, 0, (LPARAM)szOutput );
      wsprintf( szOutput, "Capacity (lowpart): %d", tgmp.Capacity.LowPart );
      SendDlgItemMessage( hWnd, 100, LB_ADDSTRING, 0, (LPARAM)szOutput );
      wsprintf( szOutput, "Remaining (lowpart): %d", tgmp.Remaining.LowPart );
      SendDlgItemMessage( hWnd, 100, LB_ADDSTRING, 0, (LPARAM)szOutput );
   }
   else
   {
      wsprintf( szOutput, "Error %d with GetTapeParameters()", dwStatus );
      SendDlgItemMessage( hWnd, 100, LB_ADDSTRING, 0, (LPARAM)szOutput );
      CloseHandle( hFile );
      return( FALSE );
   }
   CloseHandle( hFile );          //  Don't forget to close the handle and exit
   return( TRUE );
}
